/*  This file is part of VIM Pal.
 *
 *  VIM Pal is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  VIM Pal is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with VIM Pal.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef PROFILE_H
#define PROFILE_H

#include <QVariantList>
#include <QStringList>
#include <QModelIndex>

class QSettings;
class QStandardItemModel;
class QStandardItem;

class Profile
{
public:
    struct Data {
        int Index, QuickFileGroup;
        QString Title, Server, Dir;
        QStringList ExpandedDirs;
        QVariantList ExpandedQuickDirs;
    };

    Profile(const Data& data);
    ~Profile();

    void setName(const QString& name);
    void setServer(const QString& name);
    void setDir(const QString& dir);
    void setIndex(int idx);
    void setExpandedDirs(const QStringList& exp);
    void setExpandedQuickDirs(int index, const QStringList& items);
    void setQuickFileGroup(int index);

    const Data& data() const
    {
        return mData;
    }

    QStandardItemModel* quickFileModel(int index) const;

    const QStringList& quickFileGroups() const
    {
        return mQuickFileGroups;
    }

    void addQuickFileGroup(const QString& name);
    void removeQuickFileGroup(int index);
    void renameQuickFileGroup(int index, const QString &name);

    void loadQuickFiles(const QVariant &set);
    QByteArray getQuickFiles();

    /*! \brief Save entire profile data to settings.
     */
    void saveProfile(QSettings& set);

    /*! \brief Save quick file data to settings.
     */
    void saveQuickFiles();

private:
    void makeTree(QDataStream &str, QStandardItemModel* model, QStandardItem *parent = 0);
    void collectTreeItems(QDataStream &str, QStandardItemModel* model, const QModelIndex& parent = QModelIndex());

    QStandardItem* fileItem(const QString& fname);

    void saveSettingsItem(const QString& name, const QVariant& value);

private:
    Data mData;

    QStringList mQuickFileGroups;
    QList<QStandardItemModel*> mQuickFiles;
};

#endif // PROFILE_H
