/*  This file is part of VIM Pal.
 *
 *  VIM Pal is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  VIM Pal is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with VIM Pal.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef QUICKFILEVIEW_H
#define QUICKFILEVIEW_H

#include <QWidget>
#include <QModelIndex>

class QTreeView;
class QModelIndex;
class QStandardItemModel;
class QStandardItem;
class QTabBar;

class Profile;

class QuickFileView: public QWidget
{
    Q_OBJECT

public:
    explicit QuickFileView(QWidget *parent = 0);

public slots:
    void setProfile(Profile* p);
    void addFile(const QString& fname);

    void saveExpandedDirs();
    void saveQuickFiles();
    void removeCurrent();
    void editCurrent();

    void resetProfile();

private slots:
    void quickFileClicked(const QModelIndex& idx);
    void quickFileActivated(const QModelIndex& idx);
    void contextMenu(const QPoint& pos);

    void addFolder();
    void removeAll();
    void sortItems();
    void addTab();
    void removeTab();
    void renameTab();

    void listChanged();

    void groupSelected(int idx);

private:
    void addItem(QStandardItem* item);

    QStandardItem* findFile(const QString& name, QStandardItem *parent = 0) const;

    /*! \brief Collect the list of expanded quick file dirs.
     */
    QStringList getExpandedDirs(const QModelIndex &parent = QModelIndex()) const;

    /*! \brief Expand the specified quick file dirs.
     */
    void expandDirs(const QStringList& dirs, const QModelIndex &parent = QModelIndex());

    void setCurrentModel(QStandardItemModel* model);

private:
    QTreeView *mQuickFileView;
    QTabBar* mTabBar;
    int mCurrentTab;

    QStandardItemModel* mCurrentModel;
    Profile* mCurrentProfile;

    QTimer* mChangeTimer;
};

#endif // QUICKFILEVIEW_H
