/*  This file is part of VIM Pal.
 *
 *  VIM Pal is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  VIM Pal is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with VIM Pal.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SETTINGS_H
#define SETTINGS_H

#include <QVariantMap>
#include <QStringList>

class Settings
{
public:
    struct Tool {
        QString Name, Command, Filter;
        bool ByDefault;
    };

    static Settings* instance();

    bool settingsDialog(QWidget* parent, QVariantMap& extraSettings);

    const QString& language() const
    {
        return mLanguage;
    }

    const QString& vimCommand() const
    {
        return mVimCommand;
    }

    int lastProfile() const
    {
        return mLastProfile;
    }

    bool asToolWindow() const
    {
        return mAsToolWindow;
    }

    bool showHidden() const
    {
        return mShowHidden;
    }

    bool singleClickOpen() const
    {
        return mSingleClickOpen;
    }

    bool changeDir() const
    {
        return mChangeDir;
    }

    bool autoQuickList() const
    {
        return mAutoQuickList;
    }

    bool openNewTabs() const
    {
        return mOpenNewTabs;
    }

    bool darkBackground() const
    {
        return mDarkBackground;
    }

    bool useSessions() const
    {
        return mUseSessions;
    }

    bool oneVimWindow() const
    {
        return mOneVimWindow;
    }

    const QString& sessionFileDir() const
    {
        return mSessionFileDir;
    }

    bool profilesIcons() const
    {
        return mProfilesIcons;
    }

    const QList<Tool>& tools() const
    {
        return mTools;
    }

private:
    Settings();

    bool mSingleClickOpen,
         mChangeDir,
         mOpenNewTabs,
         mDarkBackground,
         mShowHidden,
         mAutoQuickList,
         mAsToolWindow,
         mUseSessions,
         mOneVimWindow,
         mProfilesIcons;

    QString mVimCommand,
            mLanguage,
            mSessionFileDir;

    int mLastProfile;

    QList<Tool> mTools;

    static Settings* sSettings;
};

#endif // SETTINGS_H
