/*  This file is part of VIM Pal.
 *
 *  VIM Pal is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  VIM Pal is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with VIM Pal.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SETTINGSDIALOG_H
#define SETTINGSDIALOG_H

#include "ui_preferences.h"

#include "settings.h"

class QStandardItemModel;

class SettingsDialog: public QDialog, public Ui::Preferences
{
    Q_OBJECT

public:
    explicit SettingsDialog(QWidget *parent = 0);

    void setTools(const QList<Settings::Tool>& tools);
    const QList<Settings::Tool> getTools() const;

    void setLanguage(const QString& lang);
    QString getLanguage() const;

private slots:
    void on_browseCmd_clicked();
    void on_addTool_clicked();
    void on_removeTool_clicked();
    void on_moveToolUp_clicked();
    void on_moveToolDown_clicked();
    void on_browseSessionDir_clicked();

    void currentToolChanged(const QModelIndex& index, const QModelIndex& previous = QModelIndex());

    void on_toolView_activated(const QModelIndex &index);

private:
    QStandardItemModel* mToolModel;

    static const QStringList sLanguageNames, sLanguageCodes;
};

#endif // SETTINGSDIALOG_H
