/*  This file is part of VIM Pal.
 *
 *  VIM Pal is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  VIM Pal is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with VIM Pal.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef VIMPAL_H
#define VIMPAL_H

#include <QMainWindow>
#include <QStack>

class QFileSystemModel;
class QModelIndex;
class QTreeView;
class QComboBox;
class QMenu;
class QTranslator;
class QToolButton;
class QListView;

class ProfileModel;
class Profile;
class QuickFileView;

class VimPal: public QMainWindow
{
    Q_OBJECT

    Q_PROPERTY(Profile* currentProfile READ currentProfile NOTIFY profileChanged)

public:
    VimPal(QWidget* parent = 0, Qt::WindowFlags f = 0);

    QSize sizeHint() const;

    Profile* currentProfile() const
    {
        return mCurrentProfile;
    }

protected:
    void closeEvent(QCloseEvent* e);
    void changeEvent(QEvent *e);

signals:
    void profileChanged(Profile* p);

private slots:
    void goHome();
    void goUp();
    void goBack();
    void goForward();
    void changeRoot(QAction* action);

    void updateRootMenu();

    void fileClick(const QModelIndex& idx);
    void fileDblClick(const QModelIndex& idx);

    void fileTreeContextMenu(const QPoint& pos);

    void editPreferences();
    void editProfiles();

    void editItems();
    void removeItems();

    void setProfile(int prof);
    void profileClicked(const QModelIndex& idx);

    void showAbout();

private:
    void selectFile(const QModelIndex& idx);
    void selectDir(const QModelIndex& idx, bool noHistory = false);
    void selectDir(const QString& dir, bool noHistory = false);
    void selectDir(const QModelIndex &idx, const QString& dir, bool noHistory);
    void deleteFile(const QModelIndex& idx);
    void renameFile(const QModelIndex& idx);
    void newFile(const QModelIndex& idx);
    void newDirectory(const QModelIndex& idx);
    void updateColors();

    void clearHistory();
    void pushHistory(const QString& path);
    void setLanguage(const QString& lang);

    QString getDir(const QModelIndex& idx);

    QStringList getExpanded(const QModelIndex& parent);

    void retranslateUi();

private:
    Profile* mCurrentProfile;

    ProfileModel* mProfileModel;

    QuickFileView* mQuickFileView;

    QFileSystemModel* mDirModel;
    QTreeView* mDirView;
    QComboBox* mProfileBox;
    QMenu* mRootMenu;

    QAction* mGoBack,
           * mGoForward,
           * mGoHome,
           * mPreferencesAction,
           * mAboutAction,
           * mQuitAction,
           * mEditAction,
           * mRemoveAction;

    QListView* mProfileView;

    QToolBar* mNavigationToolbar,
            * mProfileToolbar;

    QToolButton* mGoUpBtn,
               * mStartBtn;

    QDockWidget* mProfileDock,
               * mQuickListDock;

    QStack<QString> mHistory, mForwardHistory;

    QTranslator* mCurrentTranslator;
};

#endif   // VIMPAL_H
